@@ -50,9 +50,9 @@ class Editor(object):
             number, _sep, path = line.partition(" ")
             path = unescapepath(path)
             if path:
-                index = int(number) - 1
                 try:
-                    files[index].dests.append(path)
+                    index = int(number)
+                    files[index - 1].dests.append(path)
                 except IndexError:
                     log.warning("invalid index in line %d: %d", i, index)
                 except ValueError:
