@@ -40,13 +40,13 @@ class FsBase(object):
 
     def realdir(self, path):
         if not path:
-            raise OSError("Invalid argument: %r" % (path,))
+            raise OSError(f"Invalid argument: {path!r}")
         path = path.rstrip('/')
         if not path:
             return "/"
         dn, bn = self.splitpath(path)
         if bn in ('.', '..'):
-            raise OSError("Invalid argument: %r" % (path,))
+            raise OSError(f"Invalid argument: {path!r}")
         if not dn:
             dn = "."
         dn = self.realpath(dn + "/")
