@@ -77,6 +77,7 @@ class Menu(object):
         self.apply_output = 'diff'
         self.always_interact = always_interact
         self.previous_choice = None
+        self.printed_conflicts = False
         self._edit_successful = True
         self.default_editor_command = default_editor_command
 
@@ -84,6 +85,13 @@ class Menu(object):
         self.quit_error = False
 
     def _readchoice(self, choices, abortchoice=None, hchoices=[]):
+        if not self.printed_conflicts:
+            self.ed.write_conflicts(out=sys.stdout, colors=self.colors)
+            self.printed_conflicts = True
+        if self.applier:
+            print(self.applier.get_stats_message(self.colors))
+        else:
+            print(self.ed.stats.get_message(colors=self.colors))
         colors = self.promptcolors
         if self.applier is None:
             c_prompt = colors.prompt
@@ -116,12 +124,11 @@ class Menu(object):
                 choices.append("add")
             if count:
                 choices.append("reset")
-            choices.append("stats")
             choices.append("quit")
             hchoices = ["recalc"]
             abortchoice = "quit"
         else:
-            choices = ["revert", "dryrun", "stats", "quit"]
+            choices = ["revert", "dryrun", "quit"]
             hchoices = []
             if self.applier.successful:
                 abortchoice = "quit"
@@ -158,15 +165,14 @@ class Menu(object):
             if self.previous_choice == "apply" and self.ed.stats.deletes == 0:
                 if "quit" in choices:
                     return "quit", False, "quit"
-        if self.previous_choice == "revert" and "edit" in choices:
+        if self.previous_choice in ("revert", "add") and "edit" in choices:
             return "edit", False, "edit"
         return None
 
     def loop(self):
         if not self.applier and not self.ed.calculated:
             self.ed.calculate_changes()
-            self.ed.write_conflicts(out=sys.stdout, colors=self.colors)
-            print(self.ed.stats.get_message(colors=self.colors))
+            self.printed_conflicts = False
         choices, hchoices, abortchoice = self._get_choices()
         choice, upper, instr = (
             self._try_quick_choice(choices)
@@ -245,7 +251,6 @@ class Menu(object):
     def choice_reset(self, choice, args, upper):
         if upper:
             self.ed.reset()
-            print(self.ed.stats.get_message(self.colors))
         else:
             self.choice_edit(choice, args, False, reset=True)
 
@@ -259,12 +264,6 @@ class Menu(object):
         self.ed.write_conflicts(sys.stdout, short=(not upper),
                                 colors=self.colors)
 
-    def choice_stats(self, choice, args, upper):
-        if self.applier:
-            print(self.applier.get_stats_message(self.colors))
-        else:
-            print(self.ed.stats.get_message(self.colors))
-
     def choice_recalc(self, choice, args, upper):
         self._signal_recalc()
 
